
def number_detect(letter):
    """Detect the nature of letter is number or not"""

    try:
        int(letter)
        return True
    except:
        return False

def collab_words_in_list(list):
    """collab word into strings"""
    return ''.join(list)


import filemod
from termcolor import colored


def collab_words_in_list(list):
    """collab word into strings"""
    return ''.join(list)


def extract_keys(txt_file_data):
    """extract keys from file"""
    characters = list(txt_file_data)
    temp = []
    keys = []
    for index in range(len(characters)):
        if characters[index] == "\n":
            for value_index in range(index, len(characters)):
                if characters[value_index] == ":":
                    keys.append(collab_words_in_list(temp))
                    temp.clear()
                    break
                elif characters[value_index] not in [":", "\n", " "]:
                    temp.append(characters[value_index])

    return keys


def extract_values(txt_file_data):
    """extract values from file"""
    temp = []
    values = []
    characters = list(txt_file_data)

    for index in range(len(characters)):
        if characters[index] == ":":
            for value_index in range(index, len(characters)):
                if characters[value_index] == "\n":
                    values.append(collab_words_in_list(temp))
                    temp.clear()
                    break
                if characters[value_index] not in [":", "'", "\n", " ", '"']:
                    temp.append(characters[value_index])
    return values


def test1(data):
    if data is None:
        print(colored('x Test 1 Fail', 'red'))
    else:
        print(colored('✓ Test 1 pass', 'green'))
        return True


def test2(data):
    if data[0:1] == "{" and data[len(data)-1] == "}":
        print(colored("✓ Test 2 pass", 'green'))
        return True
    elif data[0:1] != "{":
        print(colored('missing { ', 'red'))
        print(colored('x Test 2 Fail', 'red'))
    else:
        print(colored('x Test 2 Fail', 'red'))
        print(colored('missing } never closed', 'red'))


def test3(data):
    if len(extract_keys(data)) == len(extract_values(data)) == data.count(":"):
        print(colored("✓ Test 3 pass", 'green'))
        return True

    print(colored("X Test 3 Fail", 'red'))
    print(colored("Uneven values or number found in the values", 'red'))


def compiles(data):
    data = filemod.reader(data)
    if test1(data) == test2(data) == test3(data):
        print(colored("All Test Passed", 'green'))
    return data



from os import read
import setuptools

from filemod import reader


classifiers=[
    'Intended Audience :: Education',
    'Operating System :: Microsoft :: Windows :: Windows 10',
    'License :: OSI Approved :: MIT License',
    "Programming Language :: Python :: 3.5",
    "Programming Language :: Python :: 3.6",
    "Programming Language :: Python :: 3.7",
    "Programming Language :: Python :: 3.8",
    "Programming Language :: Python :: 3.9",
    "Programming Language :: Python :: 3.10"
]
setuptools.setup(
    name="json_txt",
    version="1.4.3",
    author="kshitij jathar",
    author_email="kshitijjathar7@gmail.com",
    description="Make Your txt work like json",
    long_description=reader('README.md'),
    long_description_content_type="text/markdown",
    url="https://github.com/kshitij1235/filemod",
    project_urls={
        "Bug Tracker": "https://github.com/kshitij1235/filemod/issues",
    },
    license='MIT',
    classifiers=classifiers,
    keywords='file',
    packages=setuptools.find_packages(),
    install_requires=['filemod']

)
import json_txt


import re

from filemod import reader
from json_txt import compiler


def number_detect(letter):
    """Detect the nature of letter is number or not"""

    try:
        int(letter)
        return True
    except:
        return False

def collab_words_in_list(list):
    """collab word into strings"""
    return ''.join(list)


def extract_keys(txt_file_data):
    """extract keys from file"""
    temp = []
    keys = []
    for index in range(len(txt_file_data)):
        if txt_file_data[index] == "\n":
            for value_index in range(index, len(txt_file_data)):
                if txt_file_data[value_index] == ":":
                    keys.append(collab_words_in_list(temp))
                    temp.clear()
                    break
                if txt_file_data[value_index] not in [":", "\n", " "]:
                    temp.append(txt_file_data[value_index])

    return keys


def generate_array(data):
    from json_txt.support_funcs import number_detect,collab_words_in_list
    array_temp=[]
    array=[]
    for array_elements in data:
        if array_elements in ["["]:
            continue 
        elif array_elements in [",","]"]:
            if number_detect(collab_words_in_list(array_temp)):
                array.append(int(collab_words_in_list(array_temp)))
            else:
                array.append(collab_words_in_list(array_temp))
            array_temp.clear()
        else:
            array_temp.append(array_elements)
    return array


def extract_values(txt_file_data):
    """extract values from file"""
    temp = []
    values = []
    for index in range(len(txt_file_data)):

        if txt_file_data[index] == ":":
           
            for index in range(index, len(txt_file_data)):               
                
                if txt_file_data[index] == "\n":
                    if temp[0]=="[":
                        values.append(list(generate_array(temp)))
                        temp.clear()  
                        continue    
                    
                    else:
                        if  number_detect(collab_words_in_list(temp)):
                            values.append(int(collab_words_in_list(temp)[1:]))
                        else:
                            values.append(collab_words_in_list(temp)[1:])
                        temp.clear()
                        break
                
                elif txt_file_data[index] not in ["'", " ", '"']:
                    temp.append(txt_file_data[index])

    return values




def extract_data(data):
    """create a dictonary"""
    keys = extract_keys(data)
    values = extract_values(data)
    return {keys[index]: values[index] for index in range(len(keys))}


def load_txt(data):
    """compiling the text file"""
    try:
        from json_txt.compiler import compiles
        return list(compiles(data))
    except:
        return list(reader(data))
